@@ -1,6 +1,6 @@
 package POE::Component::Client::DNS::Recursive;
 {
-  $POE::Component::Client::DNS::Recursive::VERSION = '1.02';
+  $POE::Component::Client::DNS::Recursive::VERSION = '1.04';
 }
 
 #ABSTRACT: A recursive DNS client for POE
@@ -17,18 +17,14 @@ use Net::DNS::Packet;
 
 my @hc_hints = qw(
 198.41.0.4
-192.58.128.30
-192.112.36.4
-202.12.27.33
+192.228.79.201
+192.33.4.12
+128.8.10.90
+192.203.230.10
 192.5.5.241
+192.112.36.4
 128.63.2.53
 192.36.148.17
-192.33.4.12
-192.228.79.201
-199.7.83.42
-128.8.10.90
-193.0.14.129
-192.203.230.10
 );
 
 sub resolve {
@@ -121,7 +117,7 @@ sub _hints_go {
      $hints = $runstate->{nameservers};
   }
   else {
-     $hints = \@hc_hints;
+     $hints = [ @hc_hints ];
   }
   $runstate->{_hints} = $hints;
   $machine->goto_state( 'hints', '_setup', Net::DNS::Packet->new('.','NS','IN'), splice( @$hints, rand($#{$hints}), 1) );
@@ -404,7 +400,7 @@ POE::Component::Client::DNS::Recursive - A recursive DNS client for POE
 
 =head1 VERSION
 
-version 1.02
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -539,7 +535,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chris Williams.
+This software is copyright (c) 2012 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
